@@ -2,10 +2,6 @@
  * This is a dummy version avoiding patent problems.
  */
 
-#ifdef RCSID
-static char rcsid[] = "$Id: lzw.c,v 1.3 1999/10/06 05:01:31 eggert Exp $";
-#endif
-
 #include <config.h>
 #include "tailor.h"
 #include "gzip.h"
